import numpy as np

def project(P,x0,max_iter=1000,tol=1e-6):
    assert len(x0.shape) == 1, "x0 must be a vector"

    x = x0.copy()
    p = len(P)
    y = np.zeros((p,x0.shape[0]))

    n = 0
    cI = float('inf')
    while n < max_iter and cI >= tol:
        cI = 0
        for i in range(0,p):
            # Update iterate
            prev_x = x.copy()
            x = P[i](prev_x - y[i,:])

            # Update increment
            prev_y = y[i,:].copy()
            y[i,:] = x - (prev_x - prev_y)

            # Stop condition
            cI += np.linalg.norm(prev_y - y[i,:])**2

            n += 1
    return x



from setuptools import setup

# Get package version
import os
version = {}
with open(os.path.join('dykstra', 'version.py')) as fp:
    exec(fp.read(), version)
__version__ = version['__version__']

setup(
    name='Dykstra',
    version=__version__,
    description="An implementation of Dykstra's projection algorithm with robust stopping criteria.",
    author='Matthew Hough',
    author_email='matt@hough.tv',
    url='https://github.com/mjhough/Dykstra/',
    download_url='https://github.com/numericalalgorithmsgroup/Dykstra/archive/v0.0.0.tar.gz',
    packages=['dykstra'],
    license='MIT',
    keywords = 'mathematics optimization projection Dykstra',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console',
        'Framework :: IPython',
        'Framework :: Jupyter',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: MIT License',
        'Operating System :: MacOS',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
        'Operating System :: Unix',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Mathematics',
        ],
    install_requires = ['numpy >= 1.11'],
    zip_safe = True,
    )

